@@ -73,7 +73,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 			result <- new("gMCPResult", graphs=sequence, alpha=alpha, pvalues=pvalues, rejected=getRejected(graph))
 			if (verbose) {
 				output <- "All p-values above alpha."
-				cat(output,"\n")
+				if (verbose!=42) cat(output,"\n") # Go figure it out ;)
 				attr(result, "output") <- output
 			}
 			return(result)
@@ -84,7 +84,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 			result <- new("gMCPResult", graphs=sequence, alpha=alpha, pvalues=pvalues, rejected=rejected)
 			if (verbose) {
 				output <- "All p-values below alpha."
-				cat(output,"\n")
+				if (verbose!=42) cat(output,"\n") # Go figure it out ;)
 				attr(result, "output") <- output
 			}
 			return(result)
@@ -101,12 +101,12 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 				if (n==2) output <- paste(output, "Only two hypotheses remaining.", sep="\n")
 				if (n==1) output <- paste(output, "Only one hypothesis remaining.", sep="\n")
 				if (n==0) output <- paste(output, "Everything allready rejected.", sep="\n")
-				cat(output,"\n")
+				if (verbose!=42) cat(output,"\n") # Go figure it out ;)
 				attr(result, "output") <- output
 			}
 			return(result)
 		} else {			
-			graph2 <- subGraph(graph, !getRejected(graph))
+			graph2 <- subgraph(graph, !getRejected(graph))
 			output <- paste(output, "Remaining hypotheses (new numeration):", paste(1:length(getNodes(graph2)),": ", getNodes(graph2), sep="",collapse="\n"), sep="\n")
 			pvalues2 <- pvalues[!getRejected(graph)]
 			allSubsets <- permutations(length(getNodes(graph2)))[-1,]
@@ -117,7 +117,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 				subset <- allSubsets[i,]
 				if(!all(subset==0)) {
 					J <- which(subset!=0)	
-					explanation[i] <- paste("Subset {",paste(J,collapse=","),"}: ",explanation[i], sep="")				
+					if (verbose) explanation[i] <- paste("Subset {",paste(J,collapse=","),"}: ",explanation[i], sep="")				
 					for (j in J) {
 						Jj <- subset!=0 & (pvalues2 <= pvalues2[j]) # & (1:n)!=j
 						#cat("j: ",j, ", Jj: ",Jj,"\n")
@@ -139,7 +139,7 @@ gMCP <- function(graph, pvalues, test, correlation, alpha=0.05,
 			result <- new("gMCPResult", graphs=sequence, alpha=alpha, pvalues=pvalues, rejected=getRejected(graph))
 			if (verbose) {
 				output <- paste(output, paste(explanation, collapse="\n"), sep="\n")
-				cat(output,"\n")
+				if (verbose!=42) cat(output,"\n") # Go figure it out ;)
 				attr(result, "output") <- output
 			}
 			return(result)
